"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const child_process_1 = require("child_process");
const fs = require("mz/fs");
const path_1 = require("path");
const rimraf = require("rimraf");
// import { promisify } from 'util';
class DependencyManager {
    // private rimrafAysnc = promisify(rimraf);
    constructor(rootPath, logger, gitHostWhitelist) {
        this.rootPath = rootPath;
        this.logger = logger;
        this.gitHostWhitelist = gitHostWhitelist;
    }
    installDependency() {
        try {
            this.runNpm();
        }
        catch (e) {
            console.debug(e);
        }
        // TO check if this is neccessary if we just download deps inside the workspace
        // await Promise.all(iterare.default(this.packageManager.packageJsonUris()).map(
        //     async uri => {
        //         console.log(uri)
        //     }
        // ))
    }
    shutdown() {
        // TODO check the best way to kill
        // TODO is this sync or async
        // console.debug('shutdowwn')
        // this.npmProcess.kill('SIGKILL')
    }
    runNpm() {
        const env = Object.create(process.env);
        env.TERM = 'dumb';
        const cwd = this.rootPath;
        // let cmd = 'yarn';
        //
        // if (existsSync(resolve(cwd, 'package-lock.json'))) {
        //     cmd = 'npm'
        // }
        if (!fs.existsSync(path_1.resolve(cwd, 'package.json'))) {
            return;
        }
        const yarnScript = require.resolve('yarn/bin/yarn.js');
        // console.error('Yarn script location' + yarnScript);
        // this.npmProcess =
        child_process_1.spawnSync(process.execPath, [
            yarnScript,
            'install',
            '--json',
            '--ignore-scripts',
            '--no-progress',
            '--non-interactive',
            '--ignore-engines',
            '--ignore-optional',
            '--no-bin-links',
            '--production==false',
        ], {
            env,
            cwd,
            stdio: 'inherit',
        });
        this.deletePackageRecursively(this.rootPath);
        // this.npmProcess.stdout.on('data', data => {
        //     console.debug('stdout: ' + data)
        // })
        //
        // this.npmProcess.stderr.on('data', data => {
        //     console.debug('stderr:' + data)
        // })
        //
        // this.npmProcess.on('error', err => {
        //     console.debug('error:' + err)
        // })
    }
    // TODO handle package softlink
    deletePackageRecursively(rootPath) {
        try {
            const names = fs.readdirSync(rootPath);
            for (const name of names) {
                const childPath = path_1.resolve(rootPath, name);
                const stat = fs.statSync(childPath);
                if (stat.isDirectory()) {
                    const packageFile = path_1.resolve(childPath, 'package.json');
                    if (fs.existsSync(packageFile)) {
                        const fileContent = fs.readFileSync(packageFile, 'utf-8');
                        // const fileContent = await fs.readFile(packageFile, 'utf-8');
                        try {
                            const json = JSON.parse(fileContent);
                            this.logger.log('Checking package:' + json.name);
                            if (json.repository) {
                                const url = new URL(json.repository.url);
                                let allowed = false;
                                for (const host of this.gitHostWhitelist) {
                                    if (url.hostname === host || url.hostname.endsWith('.' + host)) {
                                        allowed = true;
                                        break;
                                    }
                                }
                                if (!allowed) {
                                    this.logger.info('Deleting package that is not whitelisted: ' + json.name + '(' + url.href + ')');
                                    try {
                                        rimraf(childPath, {}, (error) => {
                                            this.logger.error(error);
                                        });
                                        // await this.rimrafAysnc(childPath, {});
                                        continue;
                                    }
                                    catch (e) {
                                        this.logger.error('Deleting repo error: ' + e.toString());
                                    }
                                }
                            }
                        }
                        catch (e) {
                            this.logger.log('Deleting repo error: ' + e);
                        }
                        const nodeModulesDir = path_1.resolve(childPath, 'node_modules');
                        if (fs.existsSync(nodeModulesDir)) {
                            this.deletePackageRecursively(nodeModulesDir);
                        }
                    }
                    else {
                        this.deletePackageRecursively(childPath);
                    }
                }
            }
        }
        catch (e) {
            this.logger.log(e);
        }
    }
}
exports.DependencyManager = DependencyManager;
//# sourceMappingURL=dependency-manager.js.map